@@ -4,7 +4,7 @@
  * See http://opensource.adnovum.ch/mod_qos/ for further
  * details.
  *
- * Copyright (C) 2007-2014 Pascal Buchbinder
+ * Copyright (C) 2007-2015 Pascal Buchbinder
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -23,7 +23,7 @@
  *
  */
 
-static const char revision[] = "$Id: qs_util.c,v 1.16 2014/06/26 19:12:08 pbuchbinder Exp $";
+static const char revision[] = "$Id: qs_util.c,v 1.18 2015/05/04 20:24:59 pbuchbinder Exp $";
 
 #include <stdio.h>
 #include <pthread.h>
@@ -34,6 +34,8 @@ static const char revision[] = "$Id: qs_util.c,v 1.16 2014/06/26 19:12:08 pbuchb
 #include <fcntl.h>
 #include <dirent.h>
 #include <unistd.h>
+#include <errno.h>
+#include <pwd.h>
 
 #include "qs_util.h"
 
@@ -298,3 +300,27 @@ void qs_deleteOldFiles(const char *file_name, int generations) {
     }
   }
 }
+
+/* user ------------------------------------------------------- */
+void qs_setuid(const char *username, const char *cmd) {
+  if(username && getuid() == 0) {
+    struct passwd *pwd = getpwnam(username);
+    uid_t uid, gid;
+    if(pwd == NULL) {
+      fprintf(stderr, "[%s] unknown user id '%s': %s", cmd, username, strerror(errno));
+      exit(1);
+    }
+    uid = pwd->pw_uid;
+    gid = pwd->pw_gid;
+    setgid(gid);
+    setuid(uid);
+    if(getuid() != uid) {
+      fprintf(stderr, "[%s] setuid failed (%s,%d)", cmd, username, uid);
+      exit(1);
+    }
+    if(getgid() != gid) {
+      fprintf(stderr, "[%s] setgid failed (%d)", cmd, gid);
+      exit(1);
+    }
+  }
+}
