@@ -4,7 +4,7 @@
  * See http://opensource.adnovum.ch/mod_qos/ for further
  * details.
  *
- * Copyright (C) 2007-2014 Pascal Buchbinder
+ * Copyright (C) 2007-2015 Pascal Buchbinder
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -29,12 +29,16 @@
 /* ----------------------------------
  * version info
  * ---------------------------------- */
-static const char man_version[] = "11.7";
-static const char man_date[] = "November 2014";
+static const char man_version[] = "11.15";
+static const char man_date[] = "July 2015";
 
 /* ----------------------------------
  * definitions
  * ---------------------------------- */
+/* huge (128kb) buffer supporting very long lines (twice as
+   much as Apache's rotatelogs uses */
+#define MAX_LINE_BUFFER 131072
+/* smaller buffer, e.g. for qslog */
 #define MAX_LINE 32768
 #define QS_HUGE_STR 2048
 #define CR 13
@@ -64,4 +68,7 @@ void qs_csUnLock();
 /* log */
 void qs_deleteOldFiles(const char *file_name, int generations);
 
+/* user */
+void qs_setuid(const char *username, const char *cmd);
+
 #endif
