@@ -6,7 +6,7 @@
  * See http://opensource.adnovum.ch/mod_qos/ for further
  * details.
  *
- * Copyright (C) 2007-2014 Pascal Buchbinder
+ * Copyright (C) 2007-2015 Pascal Buchbinder
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -25,7 +25,7 @@
  *
  */
 
-static const char revision[] = "$Id: qslogger.c,v 1.15 2014/01/09 08:13:07 pbuchbinder Exp $";
+static const char revision[] = "$Id: qslogger.c,v 1.19 2015/05/04 20:24:59 pbuchbinder Exp $";
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -45,8 +45,6 @@ static const char revision[] = "$Id: qslogger.c,v 1.15 2014/01/09 08:13:07 pbuch
 // [Wed Mar 28 22:40:41 2012] [warn] 
 #define QS_DEFAULTPATTERN "^\\[[0-9a-zA-Z :]+\\] \\[([a-z]+)\\] "
 
-// huge (2mb) buffer supporting very long long lines
-#define MAX_LINE_BUFFER 2097152
 #define QS_MAX_PATTERN_MA 2
 
 static int m_default_severity = LOG_NOTICE;
@@ -231,7 +229,7 @@ static void usage(const char *cmd, int man) {
   if(man) {
     printf(".SH SYNOPSIS\n");
   }
-  qs_man_print(man, "%s%s [-r <expression>] [-t <tag>] [-f <facility>] [-l <level>] [-d <level>] [-p]\n",  man ? "" : "Usage: ", cmd);
+  qs_man_print(man, "%s%s [-r <expression>] [-t <tag>] [-f <facility>] [-l <level>] [-d <level>] [-u <name>] [-p]\n",  man ? "" : "Usage: ", cmd);
   printf("\n");
   if(man) {
     printf(".SH DESCRIPTION\n");
@@ -268,6 +266,10 @@ static void usage(const char *cmd, int man) {
   if(man) printf("\n");
   qs_man_print(man, "     Defines the syslog facility. Default is 'daemon'.\n");
   if(man) printf("\n.TP\n");
+  qs_man_print(man, "  -u <name>\n");
+  if(man) printf("\n");
+  qs_man_print(man, "     Becomes another user, e.g. www-data.\n");
+  if(man) printf("\n.TP\n");
   qs_man_print(man, "  -l <level>\n");
   if(man) printf("\n");
   qs_man_print(man, "     Defines the minimal severity a message must have in order to\n");
@@ -315,6 +317,7 @@ int main(int argc, const char * const argv[]) {
   int severity = LOG_DEBUG;
   int level = LOG_INFO;
   const char *regexpattern = QS_DEFAULTPATTERN;
+  const char *username = NULL;
   regex_t preg;
   if(cmd == NULL) {
     cmd = (char *)argv[0];
@@ -337,6 +340,10 @@ int main(int argc, const char * const argv[]) {
 	const char *severityname = *(++argv);
         severity = qsgetprio(severityname, strlen(severityname));
       }
+    } else if(strcmp(*argv,"-u") == 0) { /* switch user id */
+      if (--argc >= 1) {
+        username = *(++argv);
+      }
     } else if(strcmp(*argv, "-d") == 0) {
       if (--argc >= 1) {
 	const char *severityname = *(++argv);
@@ -370,7 +377,10 @@ int main(int argc, const char * const argv[]) {
     exit(1);
   }
 
+  qs_setuid(username, cmd);
+
   openlog(tag ? tag : getlogin(), 0, facility);
+
   // start reading from stdin
   while(fgets(line, MAX_LINE_BUFFER, stdin) != NULL) {
     line_len = strlen(line) - 1;
@@ -392,5 +402,6 @@ int main(int argc, const char * const argv[]) {
       fflush(stdout);
     }
   }
+  free(line);
   return 0;
 }
