@@ -7,7 +7,7 @@
  * See http://opensource.adnovum.ch/mod_qos/ for further
  * details.
  *
- * Copyright (C) 2007-2014 Pascal Buchbinder
+ * Copyright (C) 2007-2015 Pascal Buchbinder
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -26,7 +26,7 @@
  *
  */
 
-static const char revision[] = "$Id: qsrotate.c,v 1.24 2014/09/10 05:46:13 pbuchbinder Exp $";
+static const char revision[] = "$Id: qsrotate.c,v 1.28 2015/05/04 20:24:59 pbuchbinder Exp $";
 
 #include <stdio.h>
 #include <string.h>
@@ -37,7 +37,6 @@ static const char revision[] = "$Id: qsrotate.c,v 1.24 2014/09/10 05:46:13 pbuch
 
 #include <stdlib.h>
 #include <unistd.h>
-#include <pwd.h>
 
 #include <pthread.h>
 
@@ -51,7 +50,6 @@ static const char revision[] = "$Id: qsrotate.c,v 1.24 2014/09/10 05:46:13 pbuch
 
 #include "qs_util.h"
 
-#define BUFSIZE        65536
 #define HUGE_STR       1024
 
 /* global variables used by main and support thread */
@@ -320,7 +318,7 @@ static void *forcedRotationThread(void *argv) {
 int main(int argc, char **argv) {
   char *username = NULL;
   int rc;
-  char buf[BUFSIZE];
+  char *buf;
   int nRead, nWrite;
   time_t now;
   struct stat st;
@@ -390,26 +388,7 @@ int main(int argc, char **argv) {
     m_counter = st.st_size;
   }
 
-  if(username && getuid() == 0) {
-    struct passwd *pwd = getpwnam(username);
-    uid_t uid, gid;
-    if(pwd == NULL) {
-      fprintf(stderr,"[%s]: ERROR, unknown user id %s\n", m_cmd, username);
-      exit(1);
-    }
-    uid = pwd->pw_uid;
-    gid = pwd->pw_gid;
-    setgid(gid);
-    setuid(uid);
-    if(getuid() != uid) {
-      fprintf(stderr,"[%s]: ERROR, setuid failed (%s,%d)\n", m_cmd, username, uid);
-      exit(1);
-    }
-    if(getgid() != gid) {
-      fprintf(stderr,"[%s]: ERROR, setgid failed (%d)\n", m_cmd, gid);
-      exit(1);
-    }
-  }
+  qs_setuid(username, m_cmd);
   
   /* set next rotation time */
   now = get_now();
@@ -426,8 +405,9 @@ int main(int argc, char **argv) {
     pthread_create(&tid, tha, forcedRotationThread, NULL);
   }
 
+  buf = calloc(1, MAX_LINE_BUFFER+1);
   for(;;) {
-    nRead = read(0, buf, sizeof buf);
+    nRead = read(0, buf, MAX_LINE_BUFFER);
     if(nRead == 0) exit(3);
     if(nRead < 0) if(errno != EINTR) exit(4);
     if(m_force_rotation) {
@@ -465,5 +445,7 @@ int main(int argc, char **argv) {
       qs_csUnLock();
     }
   }
+  memset(buf, 0, MAX_LINE_BUFFER);
+  free(buf);
   return 0;
 }
