@@ -6,7 +6,7 @@
  * See http://opensource.adnovum.ch/mod_qos/ for further
  * details.
  *
- * Copyright (C) 2010-2014 Pascal Buchbinder
+ * Copyright (C) 2010-2015 Pascal Buchbinder
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -28,7 +28,7 @@
  *
  */
 
-static const char revision[] = "$Id: qssign.c,v 1.30 2014/01/09 08:13:07 pbuchbinder Exp $";
+static const char revision[] = "$Id: qssign.c,v 1.35 2015/05/04 20:24:59 pbuchbinder Exp $";
 
 #include <stdio.h>
 #include <unistd.h>
@@ -53,7 +53,6 @@ static const char revision[] = "$Id: qssign.c,v 1.30 2014/01/09 08:13:07 pbuchbi
 #include "qs_util.h"
 
 #define SEQDIG "12"
-#define MAX_STRING_LEN 32768
 
 #define QS_END "qssign---end-of-data"
 
@@ -367,12 +366,12 @@ static void qs_set_format(char *s) {
  */
 static void qs_sign(const char *sec) {
   int sec_len = strlen(sec);
-  char line[MAX_LINE];
+  char *line = calloc(1, MAX_LINE_BUFFER+1);
   int dig = atoi(SEQDIG);
   /* <data> ' ' <sequence number> '#' <hmac>*/
-  int line_size = sizeof(line) - 1 - dig - 1 - (2*HMAC_MAX_MD_CBLOCK) - 1;
+  int line_size = MAX_LINE_BUFFER - 1 - dig - 1 - (2*HMAC_MAX_MD_CBLOCK) - 1;
   int line_len;
-  while(fgets(line, sizeof(line), stdin) != NULL) {
+  while(fgets(line, MAX_LINE_BUFFER, stdin) != NULL) {
     line_len = strlen(line) - 1;
     while(line_len > 0) { // cut tailing CR/LF
       if(line[line_len] >= ' ') {
@@ -394,8 +393,8 @@ static long qs_verify(const char *sec) {
   int sec_len = strlen(sec);
   long err = 0; // errors
   long lnr = 0; // line number
-  char line[MAX_LINE];
-  int line_size = sizeof(line);
+  char *line = calloc(1, MAX_LINE_BUFFER+1);
+  int line_size = MAX_LINE_BUFFER;
   int line_len;
   m_nr = -1; // sequence number
   while(fgets(line, line_size, stdin) != NULL) {
@@ -491,7 +490,7 @@ static long qs_verify(const char *sec) {
 }
 
 static void qs_failedexec(const char *msg, const char *cmd, apr_status_t status) {
-  char buf[MAX_STRING_LEN];
+  char buf[MAX_LINE];
   apr_strerror(status, buf, sizeof(buf));
   fprintf(stderr, "ERROR %s '%s': '%s'\n", msg, cmd, buf);
   exit(1);
@@ -518,7 +517,7 @@ static char *qs_readpwd(apr_pool_t *pool, const char *prg) {
   apr_table_t *a = qs_args(pool, prg);
   int i;
   apr_procattr_t *attr;
-  apr_size_t len = MAX_STRING_LEN;
+  apr_size_t len = MAX_LINE;
   char *buf = apr_pcalloc(pool, len);
 
   args = apr_pcalloc(pool, (apr_table_elts(a)->nelts + 1) * sizeof(const char *));
@@ -582,7 +581,7 @@ static void usage(char *cmd, int man) {
   if(man) {
     printf(".SH SYNOPSIS\n");
   }
-  qs_man_print(man, "%s%s -s|S <secret> [-e] [-v]\n", man ? "" : "Usage: ", cmd);
+  qs_man_print(man, "%s%s -s|S <secret> [-e] [-v] [-u <name>]\n", man ? "" : "Usage: ", cmd);
   printf("\n");
   if(man) {
     printf(".SH DESCRIPTION\n");
@@ -613,6 +612,10 @@ static void usage(char *cmd, int man) {
   qs_man_print(man, "  -v\n");
   if(man) printf("\n");
   qs_man_print(man, "     Verification mode checking the integrity of signed data.\n");
+  if(man) printf("\n.TP\n");
+  qs_man_print(man, "  -u <name>\n");
+  if(man) printf("\n");
+  qs_man_print(man, "     Becomes another user, e.g. www-data.\n");
   printf("\n");
   if(man) {
     printf(".SH EXAMPLE\n");
@@ -651,6 +654,7 @@ int main(int argc, const char * const argv[]) {
   apr_pool_t *pool;
   int verify = 0;
   char *cmd = strrchr(argv[0], '/');
+  const char *username = NULL;
   if(cmd == NULL) {
     cmd = (char *)argv[0];
   } else {
@@ -674,10 +678,16 @@ int main(int argc, const char * const argv[]) {
       verify = 1;
     } else if(strcmp(*argv,"-e") == 0) {
       m_logend = 1;
+    } else if(strcmp(*argv,"-u") == 0) { /* switch user id */
+      if (--argc >= 1) {
+        username = *(++argv);
+      }
     } else if(strcmp(*argv,"-?") == 0) {
       usage(cmd, 0);
     } else if(strcmp(*argv,"-help") == 0) {
       usage(cmd, 0);
+    } else if(strcmp(*argv,"--help") == 0) {
+      usage(cmd, 0);
     } else if(strcmp(*argv,"--man") == 0) {
       usage(cmd, 1);
     }
@@ -688,6 +698,9 @@ int main(int argc, const char * const argv[]) {
   if(m_sec == NULL) {
     usage(cmd, 0);
   }
+
+  qs_setuid(username, cmd);
+
   if(verify) {
     long err = qs_verify(m_sec);
     if(err != 0) {
